---
title: <span class="badge object-type-scalar"></span> Hryvnias
---
# <span class="badge object-type-scalar"></span> Hryvnias

Currency: Hryvnias (₴)

## Definition

```python
# Currency: Hryvnias (₴)
Hryvnias: typing.Literal["currencyUAH"] = "currencyUAH"
```
